@@ -27,7 +27,6 @@ DISPLAY OPTIONS
   --no-quotes                don't quote file names with spaces
   --hyperlink                display entries as hyperlinks
   -w, --width COLS           set screen width in columns
-  --smart-group              only show group if it has a different name from owner
 
 
 FILTERING AND SORTING OPTIONS
@@ -55,6 +54,7 @@ LONG VIEW OPTIONS
   -b, --binary               list file sizes with binary prefixes
   -B, --bytes                list file sizes in bytes, without any prefixes
   -g, --group                list each file's group
+  --smart-group              only show group if it has a different name from owner
   -h, --header               add a header row to each column
   -H, --links                list each file's number of hard links
   -i, --inode                list each file's inode number
@@ -70,7 +70,7 @@ LONG VIEW OPTIONS
                              full-iso, relative, or a custom style with '+' as
                              prefix. Ex: '+%Y/%m/%d')
   --total-size               show the size of a directory as the size of all
-                             files and directories inside
+                             files and directories inside (unix only)
   --no-permissions           suppress the permissions field
   -o, --octal-permissions    list each file's permission in octal format
   --no-filesize              suppress the filesize field
